#!/usr/bin/env bash

set -euo pipefail

. $(dirname "$0")/flux-version-check.sh

flux install \
  --network-policy=false \
  --watch-all-namespaces=true \
  --namespace=flux-system

# get current git branch name
branch=${CI_COMMIT_REF_NAME:-}
[ -z "$branch" ] && branch=$(git rev-parse --abbrev-ref HEAD)

echo "Tracking branch $branch for https://open.greenhost.net/openappstack/openappstack flux repo"

# Generate oauth secrets to link all the apps to SSO
python "$(dirname "$0")/generate_secrets.py" oauth

flux create source git openappstack \
  --url=https://open.greenhost.net/openappstack/openappstack \
  --branch=$branch \
  --interval=1h

flux create kustomization openappstack \
  --source=GitRepository/openappstack \
  --path="./flux2/cluster/base" \
  --prune=true \
  --interval=1h
